@@ -47,11 +47,11 @@
 
 #include "snd-strings.h"
 
-#define SND_DATE "17-Nov-24"
+#define SND_DATE "6-Jan-24"
 #ifndef SND_VERSION
-#define SND_VERSION "24.9"
+#define SND_VERSION "25.0"
 #endif
-#define SND_MAJOR_VERSION "24"
-#define SND_MINOR_VERSION "9"
+#define SND_MAJOR_VERSION "25"
+#define SND_MINOR_VERSION "0"
 
 #endif
