@@ -26,6 +26,14 @@
 (define fft-size (ash 1 17))
 (define little-size 1000000)
 
+(unless (defined? 'complex-vector)
+  (define complex-vector vector)
+  (define* (make-complex-vector len (init 0.0)) (make-vector len init complex?))
+  (define complex-vector-ref vector-ref)
+  (define complex-vector-set! vector-set!)
+  (define complex-vector? vector?)
+  (set! *#readers* (cons (cons #\c (lambda (s) (apply vector (read)))) *#readers*)))
+
 
 ;; --------------------------------------------------------------------------------
 (format () "complex fft...~%")
@@ -36,9 +44,9 @@
 	 (j 0))
 	((= i n))
       (if (> j i)
-	  (let ((temp (vector-ref data j)))
-	    (vector-set! data j (vector-ref data i))
-	    (vector-set! data i temp)))
+	  (let ((temp (complex-vector-ref data j)))
+	    (complex-vector-set! data j (complex-vector-ref data i))
+	    (complex-vector-set! data i temp)))
       (let ((m (/ n 2)))
 	(do () 
 	    ((not (<= 2 m j)))
@@ -61,9 +69,9 @@
 		 (i ii (+ i mmax))
 		 (j (+ ii prev) (+ j mmax)))
 		((>= jj pow))
-	      (set! tc (* wc (vector-ref data j)))
-	      (vector-set! data j (- (vector-ref data i) tc))
-	      (vector-set! data i (+ (vector-ref data i) tc)))
+	      (set! tc (* wc (complex-vector-ref data j)))
+	      (complex-vector-set! data j (- (complex-vector-ref data i) tc))
+	      (complex-vector-set! data i (+ (complex-vector-ref data i) tc)))
 	    (set! wc (* wc wpc)))
 	  (set! prev mmax))))
     data))
@@ -75,18 +83,18 @@
 	  (mxloc 0))
       (do ((i 0 (+ i 1)))
 	  ((= i fft-size))
-	(set! pk (magnitude (vector-ref fvr i)))
+	(set! pk (magnitude (complex-vector-ref fvr i)))
 	(when (> pk mx)
 	  (set! mx pk)
 	  (set! mxloc i)))
       (format () "~A ~A~%" mxloc (/ (* 2 (sqrt mx)) fft-size))
       (format () "~A ~A~%" (magnitude (fvr 4)) (magnitude (fvr (- fft-size 4)))))
-    (vector-set! fvr 4 0.0)
-    (vector-set! fvr (- fft-size 4) 0.0)
+    (complex-vector-set! fvr 4 0.0)
+    (complex-vector-set! fvr (- fft-size 4) 0.0)
     (let ((mx 0.0))
       (do ((i 0 (+ i 1)))
 	  ((= i fft-size))
-	(set! mx (max mx (magnitude (vector-ref fvr i)))))
+	(set! mx (max mx (magnitude (complex-vector-ref fvr i)))))
       (format () "noise: ~A~%" mx))))
 
 (define (complex-test)
@@ -95,7 +103,7 @@
     (do ((i 0 (+ i 1))
 	 (x 0.0 (+ x scl)))
 	((= i fft-size))
-      (vector-set! fvr i (sin x)))
+      (complex-vector-set! fvr i (sin x)))
     (complex-fft fvr fft-size 1)
     (complex-checker fvr)
     (complex-fft #f 0 0)
@@ -130,7 +138,7 @@
       (do ((lg 0 (+ lg 1))
 	   (mmax 2 (* mmax 2))
 	   (pow (/ n 2) (/ pow 2))
-	   (theta (rationalize (* pi dir)) (* theta 0.5)))
+	   (theta (rationalize (* pi dir)) (* theta 1/2)))
 	  ((= lg ipow))
 	(let ((wpr (rationalize (cos theta)))
 	      (wpi (rationalize (sin theta)))
