@@ -13,6 +13,7 @@
 		     ("tari.scm" . "v-ari")
 		     ("tauto.scm" . "v-auto")
 		     ("tbig.scm" . "v-big")
+		     ("tbit.scm" . "v-bit")
 		     ("tcase.scm" . "v-case")
 		     ("tclo.scm" . "v-clo")
 		     ("tcomplex.scm" . "v-complex")
@@ -102,15 +103,16 @@
 	 (list "repl" "tread.scm")
 	 (list "repl" "tcopy.scm")
 	 (list "repl" "trclo.scm")
-	 (list "repl" "tmat.scm")
 	 (list "repl" "tload.scm")
+	 (list "repl" "tmat.scm")
 	 (list "repl" "fbench.scm")
 	 (list "repl" "tsort.scm")
 	 (list "repl" "titer.scm")
 	 (list "repl" "tio.scm")
+	 (list "repl" "tbit.scm")
 	 (list "repl" "tobj.scm")
-	 (list "repl" "tmac.scm")
 	 (list "repl" "teq.scm")
+	 (list "repl" "tmac.scm")
 	 (list "repl" "tcomplex.scm")
 	 (list "repl" "tcase.scm")
 	 (list "repl" "tmap.scm")
@@ -128,9 +130,9 @@
 	 (list "repl" "tset.scm")
 	 (list "repl" "tleft.scm")
 	 (list "repl" "tmisc.scm")
+	 (list "repl" "tgc.scm")
 	 (list "repl" "tclo.scm")
 	 (list "repl" "tlamb.scm")
-	 (list "repl" "tgc.scm")
 	 (list "repl" "thash.scm")
 	 (list "repl" "cb.scm")
 	 (list "repl" "tmap-hash.scm")
